==> ocre_v0_041.tgz: ocre-0.041/ocre/src/repasa.c <==

#include <stdio.h>

#include "atributos.h"
#include "base.h"
#include "diccionarios.h"
#include "grises.h"
#include "glifos.h"
#include "imagx.h"
#include "inclina.h"
#include "opcns.h"
#include "pinta.h"
#include "reconoce.h"
// #include "segmenta0.h"
#include "segmenta.h"
#include "segmenta2.h"
#include "tarea.h"

int incognitasSeguidas (tnodolglifo nodolGlifo)
{
  int i;
  i = 0;
  while ((nodolGlifo !=  0L) &&
         (nodolGlifo->aglifo->recon == reconNulo) &&
         (nodolGlifo->aglifo->tipo  == glifCar) ) {
    i++ ;
    nodolGlifo = nodolGlifo->siguiente;
    }
  return i;
}

int juntaSipuede2glifos (tnodolglifo nodolGlifo)
{
  int resul;
  tglifo glifoNuevo;
  resul = FALSE;
  glifoNuevo = glifoUnionConSiguiente (nodolGlifo);
  if (glifoNuevo != 0L) {
    reconoceChar (glifoNuevo, 4); 
    if (glifoNuevo->recon != reconNulo) {
      substituye2glifospor1 (nodolGlifo, glifoNuevo);
      resul = TRUE;
      }
    }
  if (d_valori >= 20)
    printf ("ocre: juntaSipuede2glifos\n") ;
  return resul;
}

Boolean pruebareSegmentandoHisV (tglifo glifo)
{
  int n;
  int bien;
  tglifo glifoNuevo;
  tvvents vvents;
  int incl;
  if (d_valori >= 20) {
    printf ("ocre.repasa.pruebareSegmentandoHisV: \n");
    describeVentana (glifo->venDeGlifo);
    }
  bien = FALSE;
  incl = glifo->venDeGlifo->incl;
  if (tomaValordeListaAtributos (glifo->venDeGlifo->atributs, "capitular") != 0L) 
    return FALSE;
  // if (!bien) return FALSE;
  if (incl == 0)
    resegmentaCar (& vvents, glifo);
  else
    return FALSE;
  if ((vvents->n > 1) && (incl == 0)){
    glifo->tipo = glifCompSec;
    glifo->listaGlifos = listadglifoNueva ();
    for (n=0; n < vvents->n; n++) {
      glifoNuevo = glifoLetNuevo ("-?");
      adoptaGlifo (glifo, glifoNuevo);
      casaGlifoVent (glifoNuevo, vvents->ventanas[n]);
      reconoceChar (glifoNuevo, 3);  /* 3 */
      if (glifoNuevo->recon != reconNulo) {
        bien = TRUE ;
        if (d_valori >= 20) {
          printf ("pruebareSegmentandoHisV:%s \n", glifoNuevo->letras);
          }
        }
      }
    if (!bien) {
      glifo->tipo = glifCar;
      glifo->listaGlifos = 0L;
      }
    }
  /**/
  else {
    /* puede ser vvents->n == 0 ? */
    if (vvents->n == 1) {
      destruyeVentana (vvents->ventanas[0]);
      }
    reconoceChar (glifo, 3); 
    // bien = glifoNuevo->recon != reconNulo;  // 20070527
    bien = glifo->recon != reconNulo;
    }
  if (incl == 0)
    vventsfree (vvents);
  /**/
  return bien;
}

int pruebaSegmentando2 (tglifo glifo)
{
  int n;
  int bien;
  tglifo glifoNuevo;
  tvvents vvents;
  if (d_valori >= 20) {
    printf ("ocre.repasa.pruebaSegmentando2: ... \n");
    describeVentana (glifo->venDeGlifo);
    }
  bien = FALSE;
  segmentaAf (& vvents, glifo, FALSE /* no agrupar */);
  if ( (vvents->n >  1) ||
      ((vvents->n == 1) &&
        ventanaMenor(vvents->ventanas[0], glifo->venDeGlifo) ) ) {
    // printf ("ocre.repasa.pruebaSegmentando2: vvents->n > 1 \n");
    glifo->tipo = glifCompSec;
    glifo->listaGlifos = listadglifoNueva ();
    for (n=0; n < vvents->n; n++) {
      glifoNuevo = glifoLetNuevo ("-?");
      adoptaGlifo (glifo, glifoNuevo);
      casaGlifoVent (glifoNuevo, vvents->ventanas[n]);
      reconoceChar (glifoNuevo, 4);  /* 3 */
      if (glifoNuevo->recon != reconNulo) {
        bien = TRUE ;
        if (d_valori >= 20) {
          printf ("pruebaSegmentando2:%s \n", glifoNuevo->letras);
          }
        }
//
      else {
	bien = bien || pruebareSegmentandoHisV (glifoNuevo);
        }
//
      }
    if (!bien) {
      glifo->tipo = glifCar;
      glifo->listaGlifos = 0L;
      }
    vventsfree (vvents);
    return bien;
    }
  else {
    // printf ("ocre.repasa.pruebaSegmentando2: vvents->n == 1 \n");
    if (vvents->n == 1) {
      destruyeVentana (vvents->ventanas[0]);
      }
    vventsfree (vvents);
    return bien;
    }
}

void pruebaSegmentando (tglifo glifo)
{
  int n;
  int bien;
  tglifo glifoNuevo;
  tvvents vvents;
  if (d_valori >= 20) {
    printf ("ocre.repasa.pruebaSegmentando: \n");
    describeVentana (glifo->venDeGlifo);
    }
  if (tomaValordeListaAtributos (glifo->venDeGlifo->atributs, "capitular") != 0L)
    return; 
  bien = FALSE;
  segmentaAf (& vvents, glifo, TRUE /* agrupar */);
  if ( (vvents->n >  1) ||
      ((vvents->n == 1) &&
        ventanaMenor(vvents->ventanas[0], glifo->venDeGlifo) ) ) {
	// puede haberse quitado un artefacto pequenyo
    glifo->tipo = glifCompSec;
    glifo->listaGlifos =  listadglifoNueva ();
    for (n=0; n < vvents->n; n++) {
      glifoNuevo = glifoLetNuevo ("-?");
      adoptaGlifo (glifo, glifoNuevo);
      casaGlifoVent (glifoNuevo, vvents->ventanas[n]);
      reconoceChar (glifoNuevo, 4);  /* 3 */
      if (glifoNuevo->recon != reconNulo) {
        bien = TRUE ;
        if (d_valori >= 20) {
          printf ("pruebaSegmentando:%s \n", glifoNuevo->letras);
          }
        }
      else {
	bien = bien || pruebareSegmentandoHisV (glifoNuevo);
        }
      }
    if (!bien) {
      glifo->tipo = glifCar;
      glifo->listaGlifos =  0L;
      }
    }
  else {
    /* puede ser vvents->n == 0 ? */
    if (vvents->n == 1) {
      destruyeVentana (vvents->ventanas[0]);
      }
    bien = pruebaSegmentando2 (glifo);
    if (! bien )
      pruebareSegmentandoHisV (glifo);
    }
  vventsfree (vvents);
}

void repasaPalabra (tglifo glifoLinea, tpgen nada)
{
  tnodolglifo nodolGlifo;
  int reconocido;
  int incogSeg;
  nodolGlifo = glifoLinea->listaGlifos->primero;
  while (nodolGlifo !=  0L) {
    if (nodolGlifo->aglifo->tipo  == glifCar){
      if (nodolGlifo->aglifo->recon == reconNulo) {
        incogSeg = incognitasSeguidas (nodolGlifo);
        reconocido = FALSE;
        if (incogSeg == 2)
          reconocido = juntaSipuede2glifos (nodolGlifo);
        if (! reconocido){
          // describeGlifo (nodolGlifo->aglifo, 0);
          pruebaSegmentando (nodolGlifo->aglifo);
	  }
        }
      }
    else if (nodolGlifo->aglifo->tipo  == glifCompSec) {
      repasaPalabra (nodolGlifo->aglifo, NULL);
      }
    nodolGlifo = nodolGlifo->siguiente;
    }
  if (d_valori >= 10)
    printf ("ocre: repasaPalabra\n") ;
}

void repasaPalabra0 (tglifo glifoLinea, tpgen nada)
{
  tnodolglifo nodolGlifo;
  nodolGlifo = glifoLinea->listaGlifos->primero;
  while (nodolGlifo !=  0L) {
    if ((nodolGlifo->aglifo->recon == reconNulo) &&
        (nodolGlifo->aglifo->tipo  == glifCar)    ) {
      reconoceChar (nodolGlifo->aglifo, 5);  /* 5 */
      }
    nodolGlifo = nodolGlifo->siguiente;
    }
  if (d_valori >= 10)
    printf ("ocre: repasaPalabra0\n") ;
}

void comocursivaPalabra (tglifo glifoPal, tpgen nada)
{
  int inclin;
  int incoga, incogd;
  tvent nvent;
  tglifo nglifoPal;
  inclin = calculaInclinacionVCuad(glifoPal->venDeGlifo);
  incoga = nincognitasEnGlifo (glifoPal) ;
  // if (numeroGlifosDesconocidos (..) > 0  y
  //     inclinado el texto)
  if ((incoga >= 2) &&
      (inclin <0 -30*256))
    {
  //   crea ventana
      copiaVentana (&nvent, glifoPal->venDeGlifo);
    // conv = tenerConvSobreVentana (glifoPal->venDeGlifo);  //??
      ponerConvenVentana (nvent, glifoPal->venDeGlifo->conv);
    //  nvent->incl = inclin;
      nvent->incl = -62*256;
  //   segmenta en cursiva la ventana
      prepara0 (nvent);      //  por que?
      segmentaCarLinIncl (nvent);
  //   glifos.ch para las ventanas.ch
  //   reconoce las letras
       nglifoPal = glifoCompPalNuevo ();
       casaGlifoVent (nglifoPal, nvent);
       nglifoPal->glifBase = glifoPal->glifBase;
       reconocePalabra (nglifoPal);
  //   cuenta incognitas
       incogd = nincognitasEnGlifo (nglifoPal) ;
       // printf ("---=> incoga: %3d, incogd: %3d\n", incoga, incogd);
  //   if va mejor con cursiva
       if (incogd < incoga) {
	 tnodolglifo nodolPal;
  //     cambia glifos y ventanas
         nodolPal = nodolglifoDeGlifo (glifoPal);
	 nodolPal->aglifo = nglifoPal;
  //     apunta y facilita otros 'comocursiva
	 }
    }
}

void repasaColumnaP (tglifo glifoColumnaP)
{
//  int nh;
//  char * tiraSel = "car";  //
  aplicaGtRFncD (glifoColumnaP, glifCompPal, repasaPalabra0, NULL);
  // consideraCursivas (glifoColumnaP);
  aplicaGtRFncD (glifoColumnaP, glifCompPal, comocursivaPalabra, NULL);
//  describeGlifo((seleccionaSubventana (glifoColumnaP->venDeGlifo, tiraSel))->glifoDeVen, 3); //
//  presentaVentana (&nh, seleccionaSubventana (glifoColumnaP->venDeGlifo, tiraSel), "sal38c.pgm", 1);
//  para ();
  if (disponiblesDiccionarios()){
    q_valori -= 2;
    // describeGlifo (seleccionaSubglifo(glifoColumnaP,"cadadr"),2);
    // printf ("-------------------------------------------\n");
    aplicaGtRFncD (glifoColumnaP, glifCompPal, repasaPalabra, NULL);
    aplicaGtRFncD (glifoColumnaP, glifCompPal, repasaPalabra, NULL);
    q_valori += 2;
    eligeDiccionarios (glifoColumnaP);
    utilizaDiccionarios (glifoColumnaP);
    aplicaGtRFncD (glifoColumnaP, glifCompPal, repasaPalabra, NULL);
    aplicaGtRFncD (glifoColumnaP, glifCompPal, repasaPalabra, NULL);
    }
  else {
    aplicaGtRFncD (glifoColumnaP, glifCompPal, repasaPalabra, NULL);
    aplicaGtRFncD (glifoColumnaP, glifCompPal, repasaPalabra, NULL);
    }
  if (d_valori >= 10)
    printf ("ocre: repasaColumnaP\n") ;
}

==> ocre_v0_042.tgz: ocre-0.042/ocre/src/repasa.c <==

#include <stdio.h>

#include "atributos.h"
#include "base.h"
#include "diccionarios.h"
#include "grises.h"
#include "glifos.h"
#include "imagx.h"
#include "inclina.h"
#include "opcns.h"
#include "pinta.h"
#include "reconoce.h"
// #include "segmenta0.h"
#include "segmenta.h"
#include "segmenta2.h"
#include "tarea.h"

int incognitasSeguidas (tnodolglifo nodolGlifo)
{
  int i;
  i = 0;
  while ((nodolGlifo !=  0L) &&
         (nodolGlifo->aglifo->recon == reconNulo) &&
         (nodolGlifo->aglifo->tipo  == glifCar) ) {
    i++ ;
    nodolGlifo = nodolGlifo->siguiente;
    }
  return i;
}

int juntaSipuede2glifos (tnodolglifo nodolGlifo)
{
  int resul;
  tglifo glifoNuevo;
  resul = FALSE;
  glifoNuevo = glifoUnionConSiguiente (nodolGlifo);
  if (glifoNuevo != 0L) {
    reconoceChar (glifoNuevo, 4); 
    if (glifoNuevo->recon != reconNulo) {
      substituye2glifospor1 (nodolGlifo, glifoNuevo);
      resul = TRUE;
      }
    }
  if (d_valori >= 20)
    printf ("ocre: juntaSipuede2glifos\n") ;
  return resul;
}

Boolean pruebareSegmentandoHisV (tglifo glifo)
{
  int n;
  int bien;
  tglifo glifoNuevo;
  tvvents vvents;
  int incl;
  if (d_valori >= 20) {
    printf ("ocre.repasa.pruebareSegmentandoHisV: \n");
    describeVentana (glifo->venDeGlifo);
    }
  bien = FALSE;
  incl = glifo->venDeGlifo->incl;
  if (tomaValordeListaAtributos (glifo->venDeGlifo->atributs, "capitular") != 0L) 
    return FALSE;
  // if (!bien) return FALSE;
  if (incl == 0)
    resegmentaCar (& vvents, glifo);
  else
    return FALSE;
  if ((vvents->n > 1) && (incl == 0)){
    glifo->tipo = glifCompSec;
    glifo->listaGlifos = listadglifoNueva ();
    for (n=0; n < vvents->n; n++) {
      glifoNuevo = glifoLetNuevo ("-?");
      adoptaGlifo (glifo, glifoNuevo);
      casaGlifoVent (glifoNuevo, vvents->ventanas[n]);
      reconoceChar (glifoNuevo, 3);  /* 3 */
      if (glifoNuevo->recon != reconNulo) {
        bien = TRUE ;
        if (d_valori >= 20) {
          printf ("pruebareSegmentandoHisV:%s \n", glifoNuevo->letras);
          }
        }
      }
    if (!bien) {
      glifo->tipo = glifCar;
      glifo->listaGlifos = 0L;
      }
    }
  /**/
  else {
    /* puede ser vvents->n == 0 ? */
    if (vvents->n == 1) {
      destruyeVentana (vvents->ventanas[0]);
      }
    reconoceChar (glifo, 3); 
    // bien = glifoNuevo->recon != reconNulo;  // 20070527
    bien = glifo->recon != reconNulo;
    }
  if (incl == 0)
    vventsfree (vvents);
  /**/
  return bien;
}

int pruebaSegmentando2 (tglifo glifo)
{
  int n;
  int bien;
  tglifo glifoNuevo;
  int porcNeg = 60; 
  tvvents vvents;
  if (d_valori >= 20) {
    printf ("ocre.repasa.pruebaSegmentando2: ... \n");
    describeVentana (glifo->venDeGlifo);
    }
  bien = FALSE;
  // segmentaAf (& vvents, glifo, FALSE /* no agrupar */);
  segmentaAf (& vvents, glifo, porcNeg, FALSE /* no agrupar */);
  if ( (vvents->n >  1) ||
      ((vvents->n == 1) &&
        ventanaMenor(vvents->ventanas[0], glifo->venDeGlifo) ) ) {
    // printf ("ocre.repasa.pruebaSegmentando2: vvents->n > 1 \n");
    glifo->tipo = glifCompSec;
    glifo->listaGlifos = listadglifoNueva ();
    for (n=0; n < vvents->n; n++) {
      glifoNuevo = glifoLetNuevo ("-?");
      adoptaGlifo (glifo, glifoNuevo);
      casaGlifoVent (glifoNuevo, vvents->ventanas[n]);
      reconoceChar (glifoNuevo, 4);  /* 3 */
      if (glifoNuevo->recon != reconNulo) {
        bien = TRUE ;
        if (d_valori >= 20) {
          printf ("pruebaSegmentando2:%s \n", glifoNuevo->letras);
          }
        }
//
      else {
	bien = bien || pruebareSegmentandoHisV (glifoNuevo);
        }
//
      }
    if (!bien) {
      glifo->tipo = glifCar;
      glifo->listaGlifos = 0L;
      }
    vventsfree (vvents);
    return bien;
    }
  else {
    // printf ("ocre.repasa.pruebaSegmentando2: vvents->n == 1 \n");
    if (vvents->n == 1) {
      destruyeVentana (vvents->ventanas[0]);
      }
    vventsfree (vvents);
    return bien;
    }
}

void pruebaSegmentando0 (tglifo glifo, tvvents vvents, int *bien)
{
  int n;
  tglifo glifoNuevo;
  glifo->tipo = glifCompSec;
  glifo->listaGlifos =  listadglifoNueva ();
  for (n=0; n < vvents->n; n++) {
    glifoNuevo = glifoLetNuevo ("-?");
    adoptaGlifo (glifo, glifoNuevo);
    casaGlifoVent (glifoNuevo, vvents->ventanas[n]);
    reconoceChar (glifoNuevo, 4);  // 3
    if (glifoNuevo->recon != reconNulo) {
      *bien = TRUE ;
      if (d_valori >= 20) {
        printf ("pruebaSegmentando:%s \n", glifoNuevo->letras);
        }
      }
    else {
      *bien = *bien || pruebareSegmentandoHisV (glifoNuevo);
      }
    }
}

void pruebaSegmentando (tglifo glifo)
{
  int bien;
  int porcNeg = 60; 
  int porcNeg2 = 80; 
  tvvents vvents;
  if (d_valori >= 12) {
    printf ("ocre.repasa.pruebaSegmentando: \n");
    describeVentana (glifo->venDeGlifo);
    }
  if (tomaValordeListaAtributos (glifo->venDeGlifo->atributs, "capitular") != 0L)
    return; 
  bien = FALSE;
  // printf ("ocre.repasa.pruebaSegmentando: sigue 1\n");  // XXx1
  // segmentaAf (& vvents, glifo, TRUE /* agrupar */);
  segmentaAf (& vvents, glifo, porcNeg, TRUE /* agrupar */);
  // printf ("ocre.repasa.pruebaSegmentando: sigue 2\n");  // XXx1
  if ( (vvents->n >  1) ||
      ((vvents->n == 1) &&
        ventanaMenor(vvents->ventanas[0], glifo->venDeGlifo) ) ) {
	// puede haberse quitado un artefacto pequenyo
    pruebaSegmentando0 (glifo, vvents, &bien) ;
    if (!bien) {
      glifo->tipo = glifCar;
      glifo->listaGlifos =  0L;
      }
    }
  else {
//
    segmentaAf (& vvents, glifo, porcNeg2, TRUE /* agrupar */);
    if ( (vvents->n >  1) ||
        ((vvents->n == 1) &&
          ventanaMenor(vvents->ventanas[0], glifo->venDeGlifo) ) ) {
	  // puede haberse quitado un artefacto pequenyo
      pruebaSegmentando0 (glifo, vvents, &bien) ;
      if (!bien) {
        glifo->tipo = glifCar;
        glifo->listaGlifos =  0L;
        }
      }
//
    else {
      /* puede ser vvents->n == 0 ? */
      // printf ("ocre.repasa.pruebaSegmentando: sigue 5\n");  // XXx1
      if (vvents->n == 1) {
        destruyeVentana (vvents->ventanas[0]);
        }
      bien = pruebaSegmentando2 (glifo);
      if (! bien )
        pruebareSegmentandoHisV (glifo);
      }
    }
  vventsfree (vvents);
}

void repasaPalabra (tglifo glifoLinea, tpgen nada)
{
  tnodolglifo nodolGlifo;
  int reconocido;
  int incogSeg;
  nodolGlifo = glifoLinea->listaGlifos->primero;
  while (nodolGlifo !=  0L) {
    if (nodolGlifo->aglifo->tipo  == glifCar){
      if (nodolGlifo->aglifo->recon == reconNulo) {
        incogSeg = incognitasSeguidas (nodolGlifo);
        reconocido = FALSE;
        if (incogSeg == 2)
          reconocido = juntaSipuede2glifos (nodolGlifo);
        if (! reconocido){
          // describeGlifo (nodolGlifo->aglifo, 0);   // Xxx
          pruebaSegmentando (nodolGlifo->aglifo);
	  }
        }
      }
    else if (nodolGlifo->aglifo->tipo  == glifCompSec) {
      repasaPalabra (nodolGlifo->aglifo, NULL);
      }
    nodolGlifo = nodolGlifo->siguiente;
    }
  if (d_valori >= 10)
    printf ("ocre: repasaPalabra\n") ;
}

void repasaPalabra0 (tglifo glifoLinea, tpgen nada)
{
  tnodolglifo nodolGlifo;
  nodolGlifo = glifoLinea->listaGlifos->primero;
  while (nodolGlifo !=  0L) {
    if ((nodolGlifo->aglifo->recon == reconNulo) &&
        (nodolGlifo->aglifo->tipo  == glifCar)    ) {
      reconoceChar (nodolGlifo->aglifo, 5);  /* 5 */
      }
    nodolGlifo = nodolGlifo->siguiente;
    }
  if (d_valori >= 10)
    printf ("ocre: repasaPalabra0\n") ;
}

void comocursivaPalabra (tglifo glifoPal, tpgen nada)
{
  int inclin;
  int incoga, incogd;
  tvent nvent;
  tglifo nglifoPal;
  inclin = calculaInclinacionVCuad(glifoPal->venDeGlifo);
  incoga = nincognitasEnGlifo (glifoPal) ;
  // if (numeroGlifosDesconocidos (..) > 0  y
  //     inclinado el texto)
  if ((incoga >= 2) &&
      (inclin <0 -30*256))
    {
  //   crea ventana
      copiaVentana (&nvent, glifoPal->venDeGlifo);
    // conv = tenerConvSobreVentana (glifoPal->venDeGlifo);  //??
      ponerConvenVentana (nvent, glifoPal->venDeGlifo->conv);
    //  nvent->incl = inclin;
      nvent->incl = -62*256;
  //   segmenta en cursiva la ventana
      prepara0 (nvent);      //  por que?
      segmentaCarLinIncl (nvent);
  //   glifos.ch para las ventanas.ch
  //   reconoce las letras
       nglifoPal = glifoCompPalNuevo ();
       casaGlifoVent (nglifoPal, nvent);
       nglifoPal->glifBase = glifoPal->glifBase;
       reconocePalabra (nglifoPal);
  //   cuenta incognitas
       incogd = nincognitasEnGlifo (nglifoPal) ;
       // printf ("---=> incoga: %3d, incogd: %3d\n", incoga, incogd);
  //   if va mejor con cursiva
       if (incogd < incoga) {
	 tnodolglifo nodolPal;
  //     cambia glifos y ventanas
         nodolPal = nodolglifoDeGlifo (glifoPal);
	 nodolPal->aglifo = nglifoPal;
  //     apunta y facilita otros 'comocursiva
	 }
    }
}

void trazaRepasa (char *pos, Boolean traz)
{
  if (traz)
    printf ("--------------------------------------------- %s\n", pos);
}

void repasaColumnaP (tglifo glifoColumnaP)
{
//  int nh;
//  char * tiraSel = "car";  //
  Boolean trazo = FALSE;  // FALSE
  if (d_valori >= 8)
    printf ("repasaColumnaP\n");
  aplicaGtRFncD (glifoColumnaP, glifCompPal, repasaPalabra0, NULL);
  // consideraCursivas (glifoColumnaP);
  aplicaGtRFncD (glifoColumnaP, glifCompPal, comocursivaPalabra, NULL);
//  describeGlifo((seleccionaSubventana (glifoColumnaP->venDeGlifo, tiraSel))->glifoDeVen, 3); //
//  presentaVentana (&nh, seleccionaSubventana (glifoColumnaP->venDeGlifo, tiraSel), "sal38c.pgm", 1);
//  para ();
  if (disponiblesDiccionarios()){
    q_valori -= 2;
    // describeGlifo (seleccionaSubglifo(glifoColumnaP,"cadadr"),2);
          trazaRepasa ("1", trazo);
    aplicaGtRFncD (glifoColumnaP, glifCompPal, repasaPalabra, NULL);
          trazaRepasa ("2", trazo);
    aplicaGtRFncD (glifoColumnaP, glifCompPal, repasaPalabra, NULL);
          trazaRepasa ("3", trazo);
    q_valori += 2;
    eligeDiccionarios (glifoColumnaP);
    utilizaDiccionarios (glifoColumnaP);
    aplicaGtRFncD (glifoColumnaP, glifCompPal, repasaPalabra, NULL);
          trazaRepasa ("4", trazo);
    aplicaGtRFncD (glifoColumnaP, glifCompPal, repasaPalabra, NULL);
          trazaRepasa ("5", trazo);
    }
  else {
          trazaRepasa ("1b", trazo);
    aplicaGtRFncD (glifoColumnaP, glifCompPal, repasaPalabra, NULL);
          trazaRepasa ("2b", trazo);
    aplicaGtRFncD (glifoColumnaP, glifCompPal, repasaPalabra, NULL);
          trazaRepasa ("3b", trazo);
    }
  if (d_valori >= 10)
    printf ("ocre: repasaColumnaP\n") ;
}
